/**

  Spago4Q - The Business Intelligence Free Platform

  Copyright (C) 2009 Engineering Ingegneria Informatica S.p.A.

  Spago4Q is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  Spago4Q is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

 **/
package it.eng.spago4q.extractors.parameterfiller;

import it.eng.spago.error.EMFUserError;
import it.eng.spago4q.bo.DataSourceParameter;
import it.eng.spago4q.bo.EOperation;
import it.eng.spago4q.bo.EOperationParameter;
import it.eng.spago4q.dao.DAOFactory;
import it.eng.spago4q.dao.IES4QFKDAO;
import it.eng.spago4q.extractors.bo.ExtractorParameter;

import java.util.ArrayList;
import java.util.List;

public class DefaultExtractionParameterFiller implements
        ExtractionParameterFiller {
    private static final String EOPERATIONPARAMETER_DAO = "EOperationParameterDAO";
    private static final String EDATASOURCEPARAMETER_DAO = "EDataSourceParameterDAO";
    private EOperation operation;

    public void setOperation(final EOperation operation) {
        this.operation = operation;
    }

    public List<ExtractorParameter> getDataSourceParameters(
            final Integer dataSourceId) throws EMFUserError {
        List<ExtractorParameter> dataSourceParameters = null;
        if (dataSourceId != null) {
            IES4QFKDAO dataSourceParameterDAO = (IES4QFKDAO) DAOFactory
                    .getDAO(EDATASOURCEPARAMETER_DAO);
            List ListEDataSourceParameter = dataSourceParameterDAO
                    .loadObjectList(dataSourceId, null, null);
            dataSourceParameters = new ArrayList<ExtractorParameter>();
            for (DataSourceParameter eDataSourceParameter : (List<DataSourceParameter>) ListEDataSourceParameter) {
                ExtractorParameter dsParameter = new ExtractorParameter(
                        eDataSourceParameter.getName(), eDataSourceParameter
                                .getValue());
                dataSourceParameters.add(dsParameter);
            }
        }
        return dataSourceParameters;
    }

    public List<ExtractorParameter> getDataSourceParameters()
            throws EMFUserError {
        List<ExtractorParameter> dataSourceParameters = null;
        if (operation != null && operation.getDataSource() != null) {
            dataSourceParameters = getDataSourceParameters(operation
                    .getDataSource().getId());
        }
        return dataSourceParameters;
    }

    public List<ExtractorParameter> getOperationParameters()
            throws EMFUserError {
        List<ExtractorParameter> operationParameters = null;
        if (operation != null) {
            operationParameters = getOperationParameters(operation.getId());
        }
        return operationParameters;
    }

    public List<ExtractorParameter> getOperationParameters(
            final Integer operationId) throws EMFUserError {
        List<ExtractorParameter> operationParameters = null;
        if (operationId != null) {
            IES4QFKDAO operationParameterDAO = (IES4QFKDAO) DAOFactory
                    .getDAO(EOPERATIONPARAMETER_DAO);
            List ListEOperationParameter = operationParameterDAO
                    .loadObjectList(operationId, null, null);
            operationParameters = new ArrayList<ExtractorParameter>();
            for (EOperationParameter eOperationParameter : (List<EOperationParameter>) ListEOperationParameter) {
                ExtractorParameter oParameter = new ExtractorParameter(
                        eOperationParameter.getName(), eOperationParameter
                                .getValue());
                operationParameters.add(oParameter);
            }
        }
        return operationParameters;

    }
}
