/**

  Spago4Q - The Business Intelligence Free Platform

  Copyright (C) 2009 Engineering Ingegneria Informatica S.p.A.

  Spago4Q is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  Spago4Q is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

 **/
package it.eng.spago4q.process.utils;

import it.eng.spago.base.SourceBean;
import it.eng.spago4q.bo.DataSource;
import it.eng.spago4q.bo.EOperation;
import it.eng.spago4q.bo.EProcess;
import it.eng.spago4q.bo.InterfaceType;
import it.eng.spago4q.source.utils.SourceTypeUtil;
import it.eng.spago4q.source.utils.TestMessage;
import it.eng.spago4q.utilities.DetailS4Q2ObjectUtil;

public class DetailOperationUtil extends DetailS4Q2ObjectUtil {

	private static final long serialVersionUID = 8100468559976479484L;
	private static final String DAO_NAME = "EOperationDAO";
	private static final String OBJ_NAME = "EOperation";
	private TestMessage testMessage;

	@Override
	protected String getDAOName() {
		return DAO_NAME;
	}

	@Override
	protected Object getObjectFromRequest(final SourceBean serviceRequest) {
		EOperation toReturn = new EOperation();
		String name = (String) serviceRequest.getAttribute("name");
		String description = (String) serviceRequest
				.getAttribute("description");

		String processId = (String) serviceRequest.getAttribute("Process_Id");
		String interfaceTypeId = (String) serviceRequest
				.getAttribute("InterfaceType_Id");
		String dataSourceId = (String) serviceRequest
				.getAttribute("dataSource_Id");
		String archiveString = (String) serviceRequest.getAttribute("archive");
		String rejectedString = (String) serviceRequest
				.getAttribute("rejected");

		boolean archive = false;

		if (archiveString != null) {
			archive = true;
		}

		boolean rejected = false;
		if (rejectedString != null) {
			rejected = true;
		}

		toReturn.setName(name);
		toReturn.setDescription(description);
		toReturn.setArchive(archive);
		toReturn.setRejected(rejected);

		EProcess process = new EProcess();
		process.setId(Integer.parseInt(processId));

		InterfaceType interfaceType = null;
		if (interfaceTypeId != null) {
			interfaceType = new InterfaceType();
			interfaceType.setId(Integer.parseInt(interfaceTypeId));
		}

		DataSource dataSource = null;
		if (dataSourceId != null) {
			dataSource = new DataSource();
			dataSource.setId(Integer.parseInt(dataSourceId));
		}

		toReturn.setInterfaceType(interfaceType);
		toReturn.setDataSource(dataSource);
		toReturn.setEProcess(process);

		return toReturn;
	}

	@Override
	protected String getObjectName() {
		return OBJ_NAME;
	}

	@Override
	protected void setObjectId(final Object object, final Integer id) {
		((EOperation) object).setId(id);
	}

	@Override
	public void updateObjectFromRequest(final SourceBean serviceRequest,
			final Integer id) throws Exception {
		super.updateObjectFromRequest(serviceRequest, id);
		String testValue = (String) serviceRequest
				.getAttribute("TESTOPERATION");
		if (testValue != null && testValue.toUpperCase().equals("TEST")) {
			testMessage = SourceTypeUtil.testOperation(id);
		}
	}

	@Override
	public void selectObject(final Integer id, final SourceBean serviceResponse)
			throws Exception {
		super.selectObject(id, serviceResponse);
		if (testMessage != null) {
			serviceResponse.setAttribute("TESTRESULT", testMessage);
		}
	}

}
